@@ -1,12 +1,10 @@
 from cgi import FieldStorage
 from cone.app import testing
 from cone.app.model import BaseNode
-from cone.fileupload.browser.fileupload import DOWNLOAD_TEMPLATE
 from cone.fileupload.browser.fileupload import filedelete_handle
 from cone.fileupload.browser.fileupload import fileupload
 from cone.fileupload.browser.fileupload import FileUploadHandle
-from cone.fileupload.browser.fileupload import I18N_MESSAGES
-from cone.fileupload.browser.fileupload import UPLOAD_TEMPLATE
+from cone.fileupload.browser.fileupload import templates
 from cone.tile import render_tile
 from cone.tile.tests import TileTestCase
 from pyramid.httpexceptions import HTTPForbidden
@@ -57,9 +55,10 @@ class ContainerFileUploadHandle(FileUploadHandle):
         return {
             'name': filename,
             'size': len(file['body']),
-            'url': '/{0}'.format(file.name),
-            'deleteUrl': '/{0}/filedelete_handle'.format(file.name),
-            'deleteType': 'GET',
+            'view_url': '/{0}'.format(file.name),
+            'download_url': '/{0}/download'.format(file.name),
+            'delete_url': '/{0}/filedelete_handle'.format(file.name),
+            'delete_type': 'GET',
         }
 
     def read_existing(self):
@@ -68,9 +67,10 @@ class ContainerFileUploadHandle(FileUploadHandle):
             files.append({
                 'name': node.name,
                 'size': len(node['body']),
-                'url': '/{0}'.format(node.name),
-                'deleteUrl': '/{0}/filedelete_handle'.format(node.name),
-                'deleteType': 'GET',
+                'view_url': '/{0}'.format(node.name),
+                'download_url': '/{0}/download'.format(node.name),
+                'delete_url': '/{0}/filedelete_handle'.format(node.name),
+                'delete_type': 'GET',
             })
         return files
 
@@ -82,15 +82,15 @@ class TestFileupload(TileTestCase):
         # Default i18n messages, upload and download templates
         self.checkOutput("""
         <script type="text/javascript">...</script>
-        """, I18N_MESSAGES)
+        """, templates.I18N_MESSAGES)
 
         self.checkOutput("""
         <script id="template-upload" type="text/x-tmpl">...</script>
-        """, UPLOAD_TEMPLATE)
+        """, templates.UPLOAD_TEMPLATE)
 
         self.checkOutput("""
         <script id="template-download" type="text/x-tmpl">...</script>
-        """, DOWNLOAD_TEMPLATE)
+        """, templates.DOWNLOAD_TEMPLATE)
 
     def test_fileupload_tile(self):
         container = ContainerNode(name='container')
@@ -160,11 +160,12 @@ class TestFileupload(TileTestCase):
         # Upload file
         res = upload_handle()
         self.assertEqual(res['files'], [{
-            'url': '/test.txt',
-            'deleteType': 'GET',
-            'deleteUrl': '/test.txt/filedelete_handle',
             'name': 'test.txt',
-            'size': 16
+            'size': 16,
+            'view_url': '/test.txt',
+            'download_url': '/test.txt/download',
+            'delete_url': '/test.txt/filedelete_handle',
+            'delete_type': 'GET'
         }])
 
         self.checkOutput("""
@@ -177,11 +178,12 @@ class TestFileupload(TileTestCase):
         request = self.layer.new_request()
         upload_handle = ContainerFileUploadHandle(container, request)
         self.assertEqual(upload_handle()['files'], [{
-            'url': '/test.txt',
-            'deleteType': 'GET',
-            'deleteUrl': '/test.txt/filedelete_handle',
             'name': 'test.txt',
-            'size': 16
+            'size': 16,
+            'view_url': '/test.txt',
+            'download_url': '/test.txt/download',
+            'delete_url': '/test.txt/filedelete_handle',
+            'delete_type': 'GET'
         }])
 
         # Test file delete handle
